# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
proc start {} {
# Settings zu Beginn
####################	
global lifefeld delt nmax can newworld
global nstates ncolors stop

set lifefeld(0) 1
set nmax 29
set newworld 1
set delt [expr $can/($nmax+1)]
set nstates 1
set ncolors 2
set stop 0 

clear
textinfo "Depending on number of states:"

textinfo "Left mouse-key sets red"
textinfo "Shift+Left mouse-key sets green"
textinfo "Ctrl+Left mouse-key sets yellow"
textinfo "Shift+Right/Middle mouse-key darkblue"
textinfo "ShiftCtrl+Right/Middle mouse-key violet"
textinfo "Right/Middle mouse-key always deletes cells"
automat_init
}


proc clear {} {
# initialisiert das lifefeld neu und nullt es
# löscht alle tags im canvas und initialisiert sie neu
######################################################
global lifefeld showfeld nmax delt can savefeld
global lightblue red blue
global actgen marker
global init

set actgen 0
set marker 0
unset lifefeld

if [info exist init] {unset init}

.ov.plot delete all
.ov.plot dtag all
#textdel 0 end

#set item [eval .ov.plot create text 0 0 -text "Generation:0"]
#.ov.plot addtag titel withtag $item
       
   .ov.right.msg.list  delete 0
   .ov.right.msg.list  insert 0  "Generation: $actgen"

set delt [expr $can/($nmax+1)]

# Initialisierung der  lifefeld und savefeld-Ränder für das mittelalterliche Weltbild
for {set i -1} {$i<=[expr $nmax+1]} {incr i} {
    set savefeld($i,-1) 0
    set savefeld(-1,$i) 0
    set savefeld($i,[expr $nmax+1]) 0
    set savefeld([expr $nmax+1],$i) 0

    set lifefeld($i,-1) 0
    set lifefeld(-1,$i) 0
    set lifefeld($i,[expr $nmax+1]) 0
    set lifefeld([expr $nmax+1],$i) 0
}

for {set i 0} {$i<=$nmax} {incr i} {
   for {set j 0} {$j<=$nmax} {incr j} {
       set lifefeld($i,$j) 0
       set savefeld($i,$j) 0

       set item [eval .ov.plot create rect [expr $i*$delt] [expr $j*$delt] [expr ($i+1)*$delt] [expr ($j+1)*$delt] -fill $blue]
       
       .ov.plot addtag showfeld($i,$j) withtag $item
       .ov.plot addtag allcells withtag $item
  
   }
}

show
}

proc runautomat {} {
# Routine der Buttons Step und Run
# Automatenlauf bis zur k-ten Generation
########################################
global show model actgen nstates generation stop rule nmax

if {$generation==0 } {set last 1000000} else {set last $generation}

for {set i 1} {$i<=$last} {incr i} {
   incr actgen

   if {$stop==1} {set last 0}
   if {$stop==-1} {return}
   if {$last==1000000} {incr last}

   switch $model {
    Wolfram {set last [min $last $nmax];wolfram $actgen $rule}
    Life Life_c
    Disease Disease
    PerBak04 {PerBak_c 0 4}
    CircularRoom6 CircularRoom
    CircularRoomN CircularRoom        
    PerBug04 {PerBug_c 0 4}
    PerBug14 {PerBug_c 1 4}    
    Beetle {beetle_c $i}    
    Diff {diff_c $i}
    Adv1DOK {adv_c $i 1 0}
    Adv1D {adv_c $i 0.1 0}
    Adv2D {adv_c $i 0.1 45}
    Leopard2 {leopard_c $i 2.0}
    Leopard6 {leopard_c $i 4.0}
    Fast-Leopard {leopard_f $actgen 4.0}
   

   }
   #textdel 0 end
   #textinfo "Generation: $actgen"
   #textinfo ""
   
   .ov.right.msg.list  delete 0
   .ov.right.msg.list  insert 0  "Generation: $actgen"

   if {$show==1} {show}
   update
   update idletasks
}
set stop 0
}


proc show {} {
# Füllen der Zellen anhand des Eintrags im lifefeld
####################################################
global lifefeld showfeld nmax model
global color rlist

#for {set i 0} { $i <= $nmax} {incr i} {
#   for {set j 0} { $j <= $nmax} {incr j} {
#      .ov.plot itemconfig showfeld($i,$j) -fill $color($lifefeld($i,$j))
#   }
#}
.ov.plot itemconfig allcells -fill $color(0)

foreach index [array names lifefeld] {
  if {$lifefeld($index)!=0} {
     set actcol $color($lifefeld($index))
#     .ov.plot itemconfig showfeld($index) -fill $color($lifefeld($index))

      if {$model=="Diff" || $model=="Leopard2" || $model=="Leopard6" || $model=="Fast-Leopard"} {
      .ov.plot itemconfig showfeld($index) -fill $actcol -outline $actcol
      } else {
      .ov.plot itemconfig showfeld($index) -fill $actcol
      }
  }
}
}

proc rndfill {} {
# Routine des Buttons Autofill
# Zufälliges setzen des lifefeld
##################################
global lifefeld savefeld baumfeld showfeld nmax delt
global color
global nstates
global model

clear
set low 0
set up $nstates
if {$model=="PerBak04"} {set low 2;set up 4}


for {set i 0} { $i <= $nmax} {incr i} {
   for {set j 0} { $j <= $nmax} {incr j} {
      set rnd [random]
      
      set lifefeld($i,$j) [expr int(floor($low+$rnd*(($up-$low)+0.2)))]
      set savefeld($i,$j) $lifefeld($i,$j) 
    
       set baumfeld($i,$j) $rnd
       .ov.plot itemconfig showfeld($i,$j) -fill $color($lifefeld($i,$j))
      }
}

# Bei Wolfram darf nur die erste Zeile gesetzt sein
if {$model=="Wolfram"} {

for {set i 0} { $i <= $nmax} {incr i} {
   for {set j 1} { $j <= $nmax} {incr j} {
       set lifefeld($i,$j) 0
       .ov.plot itemconfig showfeld($i,$j) -fill $color($lifefeld($i,$j))
      }

}
}
}


proc fill {num} {
# Routine des Buttons Autofill
# Setzen des lifefeld mit num
##################################
global lifefeld savefeld showfeld nmax delt
global color
global nstates

clear
for {set i 0} { $i <= $nmax} {incr i} {
   for {set j 0} { $j <= $nmax} {incr j} {

       set lifefeld($i,$j) $num
       set savefeld($i,$j) $num
      .ov.plot itemconfig showfeld($i,$j) -fill $color($lifefeld($i,$j))

   }
}
}

proc cellclick {x y cell} {
# Routine der Maussteuerung
# Füllt die Zellen entsprechend der Bindings
############################################

global lifefeld savefeld nmax delt
global can
global color nstates

# Bestimmung der angeklickten Zelle

for {set k 0} { $k <= $nmax} {incr k} {
	
   if { $x>=[expr $k*$delt] && $x<=[expr ($k+1)*$delt] } {set i $k}
   if { $y>=[expr $k*$delt] && $y<=[expr ($k+1)*$delt] } {set j $k}
}

set lifefeld($i,$j) [min $cell $nstates]
set savefeld($i,$j) [min $cell $nstates]

.ov.plot itemconfig showfeld($i,$j) -fill $color($lifefeld($i,$j))
}
