# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
proc calc_wei {} {
global xmin xdelt pxmin pxdelt
global ymin ydelt pymin pydelt
global nmax
global plotFontN plotFontS plotFontT
global boldFontN boldFontS boldFontT
global lamda s
global exec_dir
global nanz sample
global can

set nanz 500
set sample 100.0

set xmin 0
set xmax 6

#set can 600
set c .ov.plot
set plotFont $plotFontN

erase .ov.plot all

set item [.ov.plot create text [expr $can/2] 20 -text "Weierstrass' Monster" \
             -font $boldFontN -anchor c]

set item [.ov.plot create text [expr $can/2] 40 \
          -text "$nmax terms, lamda= $lamda, s= $s" \
             -font $plotFontN -anchor c]

# Extracting data
#-----------------
set outdelt 0.005

set data [exec $exec_dir/wei $nmax $lamda $s $xmin $xmax $outdelt]


set len [llength $data]
set ymin [lindex $data [expr $len-2]]
set ymax [lindex $data [expr $len-1]]
set data [lrange $data 0 [expr $len-3]]

set xdelt [expr $xmax-$xmin]
set ydelt [expr $ymax-$ymin]

# Settings of plot

set pxmin 80
set pxmax [expr $can - 30]
set pymin [expr $can - 30]
set pymax 50

set pxdelt [expr $pxmax -$pxmin]
set pydelt [expr $pymax -$pymin]
 
# Plotting of x-axis and y axis
#--------------------------

set item [$c create line $pxmin $pymin $pxmin $pymax -width 1.5]
$c addtag axis withtag $item

set item [$c create line $pxmin $pymin $pxmax $pymin -width 1.5]
$c addtag axis withtag $item

# Calculating of normalizing factor for the plot
#--------------------------

# Plotting of x-axis labels
#--------------------------

for {set i 0} {$i <= 6} {incr i} {
    set xlabel [expr $xmin + ($i*$xdelt/6.0)]
    set xoff [nnx $xlabel]

   scan $xlabel %u xtext
   set item [$c create line $xoff $pymin $xoff [expr $pymin+5] -width 2]
   $c addtag axis withtag $item
   set item [$c create text $xoff [expr $pymin+10] -text $xtext \
       -anchor n -font   $plotFont]
   $c addtag axis withtag $item
}

# Plotting of y-axis labels
#--------------------------

for {set i 0} {$i <= 6} {incr i} {
    set ylabel [expr $ymin + ($i*$ydelt/6.0)]
    set ytext [format "%10.3g" $ylabel]
    set yoff [nny $ylabel]

    set item [$c create line [expr $pxmin-5] $yoff $pxmin $yoff -width 2]
    $c addtag axis withtag $item
    set item [$c create text [expr $pxmin-10] $yoff -text $ytext \
          -anchor e -font     $plotFont]
    $c addtag axis withtag $item
}



# Preparing data for plot
#------------------------
set plotdata {}
set poutdelt [expr $outdelt*$pxdelt/$xdelt]

set px [nnx $xmin]
set py [lindex $data 0]
set py [nny $py]

append plotdata $px " " $py " "

set dat [lrange $data 1 end]
set fac [expr $pydelt/$ydelt]

foreach y $dat {
    set px [expr $px+$poutdelt]
    append plotdata $px " " [expr $pymin+($y-$ymin)*$fac] " "
}


# Plotting one data set
#------------------------
    set item [eval {$c create line} $plotdata  {-width 1 -fill black}]


# Calculating Dimension
#------------------------

set delt \
[exec $exec_dir/wei2 $nmax $lamda $s $xmin $xmax $sample $nanz]
puts $delt

set item [.ov.plot create text [expr $can/2] 60   -text "Fractal Dimension estimation=$delt"   -font $plotFontN -anchor c]


}


