# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
proc fracControl {} {
global can ovc
global boldFontN

set ovc .ov.right.control

frame $ovc
pack $ovc

#toplevel $ovc
#wm title $ovc { Control panel }
#wm geometry $ovc "250x300+610+300"
#wm geometry $ovc "+610+300"

global mode maxnum nmax big tick
global which name
global lamda s
set s 1
set lamda 0
set which dragon
set mode right
set nmax 1
set stop 0
set maxnum 15
set tick 5
set big 5

frame $ovc.left
pack $ovc.left

# Initializing of sliders
#------------------------

menubutton $ovc.left.which -text Fractal -menu $ovc.left.which.menu -font $boldFontN -relief raised
pack $ovc.left.which -pady 10
set m [menu $ovc.left.which.menu -tearoff 0]

set labels {dragon koch cantor weierstrass sierpinski pythagoras sunflower}

set name(dragon)   "Highway dragon"
set name(koch)   "Koch Curve"
set name(cantor)  "Cantor Set"
set name(weierstrass) "Weierstrass Monster" 
set name(sierpinski)  "Sierpinski Triangle"
set name(pythagoras)   "Pythagoras Tree"
set name(sunflower)  "Sunflower"

foreach lab $labels {
  $m add radio -label $name($lab) -variable which   -value $lab -font $boldFontN -command {

   $ovc.right.lamda.l config -state disabled
   $ovc.right.lamda.val config -state disabled
   $ovc.right.s.l config -state disabled
   $ovc.right.s.val config -state disabled
   $ovc.right.mode config -state disabled

switch $which {
weierstrass { $ovc.right.lamda.l config -state normal -text "Parameter l:"
                     $ovc.right.lamda.val config -state normal -increment 0.25 -from 0.25 -to 2.0
                     $ovc.right.s.l config -state normal -text "Parameter s:"
                     $ovc.right.s.val config -state normal -from -0.5 -to 10.0  -increment 0.5 
                     set maxnum 30
                     set helpn 15
                     set tick 5
                     set big 10
                     set s 1.5
                     set lamda 1.5
                     textinfo "Weierstrass' Monster:"
                     textinfo "The function is continuous, but differentiable nowhere "
                     textinfo " f(x) =sum_0^N  l^(k*(s-2))*sin(l^(k*t))"
                } 
koch        {$ovc.right.mode config -state normal
                 set maxnum 5
                 set helpn 1
                 set tick 5
                 set big 10
                } 

sierpinski  {
                 set maxnum 7
                 set helpn 1
                 set tick 5
                 set big 10
                 } 

dragon      {$ovc.right.mode config -state normal
                    set maxnum 15
                    set helpn 1
                    set tick 5
                    set big 10
                  } 

cantor      {  set maxnum 5
                   set helpn 1
                   set tick 5
                   set big 10
                 } 

pythagoras  {set maxnum 50
                    set helpn 1
                    set tick 5
                    set big 10
                   } 

sunflower  {
                  set lamda 10
                  set s 0.1
                  $ovc.right.lamda.l config -state normal  -text "Angle"
                  $ovc.right.lamda.val config -state normal -increment 1.0 -from 0.0 -to 360.0
                  $ovc.right.s.l config -state normal  -text "Radius increment" 
                  $ovc.right.s.val config -state normal -increment 0.01 -from 0.01 -to 0.2
                 set maxnum 500
                 set helpn 400
                 set tick 100
                 set big 100
            } 
}
setname $ovc.left.which $name($which)
$ovc.left.num config -to $maxnum -bigincrement $big -tickinterval $tick
set nmax $helpn
}

}


scale $ovc.left.num -from 0 -to $maxnum\
      -variable nmax \
      -length 200 \
      -orient horizontal -label "Iteration steps"       \
      -tickinterval $tick -showvalue true -resolution 1 \
      -bigincrement $big -font $boldFontN

pack $ovc.left.num -fill x
#bind $ovc.left.num <ButtonRelease-1> {calc_frac}

button $ovc.left.calc -text {Calculate} -command {calc_frac} -font $boldFontN
pack $ovc.left.calc -fill x


frame $ovc.right
pack $ovc.right

menubutton $ovc.right.mode -text Direction  -font $boldFontN -menu $ovc.right.mode.menu
pack $ovc.right.mode
set m [menu $ovc.right.mode.menu -tearoff 0]

set labels {right left alternate random}

foreach lab $labels {
  $m add radio -label $lab -variable mode -font $boldFontN
}

frame $ovc.right.lamda
pack $ovc.right.lamda -fill x

label $ovc.right.lamda.l -text "Parameter l:" -font $boldFontN
pack $ovc.right.lamda.l -side left
spinbox $ovc.right.lamda.val -textvariable lamda -from 0.25 -to 2.0 \
                        -increment 0.25 -format %4.2f -state disabled -font $boldFontN
pack $ovc.right.lamda.val -side right


frame $ovc.right.s
pack $ovc.right.s
label $ovc.right.s.l -text "Parameter s      :" -font $boldFontN
pack $ovc.right.s.l -side left
spinbox $ovc.right.s.val -textvariable s -from -0.5 -to 10.0 \
                        -increment 0.5 -format %4.2f -state disabled -font $boldFontN
pack $ovc.right.s.val -side right


frame $ovc.right.misc
pack $ovc.right.misc -side bottom -pady 10

 
button $ovc.right.misc.ps -text {PS print} \
       -command {printout} -font $boldFontN 
pack $ovc.right.misc.ps -fill x

$ovc.left.which.menu invoke $name($which)

}


