# TigerGraphics Math and Fractal Tool 1.2.2 Copyright (C) 2023, Cora Kohlmeier, Frank Hamberg
#
# Example 37-3
# A min max scale canvas example.
#

proc Scale2 {w min max Min Max {width {}} {height {}} } {
	global scale2
	global boldFontN boldFontS boldFontT
	set border 2
	if {$width == {}} {
		# Set the long dimension, in pixels
		set width [expr $Max - $Min]
	}
	if {$height == {}} {
		# Set the height dimension, in pixels
		set height 12
	}
	# Save parameters
	set scale2($w,scale) [expr ($Max-$Min)/$width]
	set scale2($w,min) $min					;# Current minimum
	set scale2($w,max) $max
	set scale2($w,Min) $Min					;# Lower bound to the scale
	set scale2($w,Max) $Max
	set scale2($w,L) 10
	set scale2($w,R) [expr $width+10]

	# Build from 0 to 100, then scale and move it later.
	# Distance between left edges of boxes is 100.
	# The box is 10 wide, therefore the slider is 110 long.
	# The left box sticks up, and the right one hangs down.

	canvas $w
# Rahmen
	$w create rect 0 0 110 [expr $height+$border/2] -fill grey -tag slider -width $border -outline grey
# Minimum Slider
	$w create rect 0 [expr $border/2] 10 [expr $height+$border/2] -fill [$w cget -background] -width $border -outline white -tag {left lbox}
# Maximun Slider
	$w create rect 100 [expr $border/2] 110 [expr $height+$border/2] -fill [$w cget -background]  -width $border -outline white -tag {right rbox}

	$w create text 5 [expr $height+5] -anchor n -text $min -tag {left lnum} -fill black -font $boldFontN
	$w create text 105 [expr $height+6] -anchor n -text $max -tag {right rnum} -fill black -font $boldFontN

	# Stretch/shrink the slider to the right length
	set scale [expr ($width+10) / 110.0]
#	set scale2($w,scale) $scale
	$w scale slider 0 0 $scale 1.0

	# move the right box and text to match new length
	set nx [lindex [$w coords slider] 2]
	$w move right [expr $nx-110] 0
	# Move everything into view
	$w move all 10 10

	# Make the canvas fit comfortably around the image
	set bbox [$w bbox all]
	set height [expr [lindex $bbox 3]+4]
	$w config -height $height -width [expr $width+30]

	# Bind drag actions
	$w bind left <Button-1> {Scale2Mark %W %x lbox}
	$w bind right <Button-1> {Scale2Mark %W %x rbox}
	$w bind left <B1-Motion> {Scale2Drag %W %x lbox}
	$w bind right <B1-Motion> {Scale2Drag %W %x rbox}

}


